@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceLister;
 # ABSTRACT: Role to give access to list_* methods.
-$Net::Kubernetes::Role::ResourceLister::VERSION = '0.18';
+$Net::Kubernetes::Role::ResourceLister::VERSION = '0.19';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
@@ -175,7 +175,7 @@ sub list_endpoints {
 		%options = @_;
 	}
 
-	my $uri = URI->new($self->path.'/enpoints');
+	my $uri = URI->new($self->path.'/endpoints');
 	my(%form) = ();
 	$form{labelSelector}=$self->_build_selector_from_hash($options{labels}) if (exists $options{labels});
 	$form{fieldSelector}=$self->_build_selector_from_hash($options{fields}) if (exists $options{fields});
@@ -218,7 +218,7 @@ Net::Kubernetes::Role::ResourceLister - Role to give access to list_* methods.
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 METHODS
 
